@@ -408,6 +408,18 @@ def test_svn_urljoin(base_url, paths_to_join, expected_result):
                 False,
             ),
         ),
+        (
+            "-r 123 http://svn.example.com/repos/sounds@100 third-party/sounds",
+            "trunk/externals",
+            "http://svn.example.org/repos/test",
+            ("third-party/sounds", "http://svn.example.com/repos/sounds", 123, False),
+        ),
+        (
+            "-r 123 http://svn.example.com/repos/sounds@150 third-party/sounds",
+            "trunk/externals",
+            "http://svn.example.org/repos/test",
+            ("third-party/sounds", "http://svn.example.com/repos/sounds", 123, False),
+        ),
     ],
 )
 def test_parse_external_definition(external, dir_path, repo_url, expected_result):
